==> cscec5b-ecxj-impl-3.0.0-20230403.024840-5-sources.jar: com/ejianc/business/ecxj/vo/SettingProductInfoVO.java <==
package com.ejianc.business.ecxj.vo;

import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * 云筑网物资实体
 * 
 * @author generator
 * 
 */
public class SettingProductInfoVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long settingId; // 招标编号
    private Long tenderProductId; // 云筑物资Id，用于改变云筑网中的状态
    private String tendersNo; // 招标编号
    private String supplierName; // 供应商名称
    private String productName; // 供应商纳税人编号
    private String productSpec; // 中标供应商联系人
    private String productUnit; // 中标供应商联系方式
    private String productPrice; // 中标供应商联系方式
    private String productRate; // 中标供应商联系方式
    private String productLowerRate; // 中标供应商联系方式
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date createTime; // 创建时间

    private List<SettingSupplierInfoVO> settingSupplierInfoEntities = new ArrayList<>(); // 设置物资清单实体

    public Long getSettingId() {
        return settingId;
    }

    public void setSettingId(Long settingId) {
        this.settingId = settingId;
    }

    public Long getTenderProductId() {
        return tenderProductId;
    }

    public void setTenderProductId(Long tenderProductId) {
        this.tenderProductId = tenderProductId;
    }

    public String getTendersNo() {
        return tendersNo;
    }

    public void setTendersNo(String tendersNo) {
        this.tendersNo = tendersNo;
    }

    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }
    public String getProductName() {
        return productName;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }

    public String getProductSpec() {
        return productSpec;
    }

    public void setProductSpec(String productSpec) {
        this.productSpec = productSpec;
    }

    public String getProductUnit() {
        return productUnit;
    }

    public void setProductUnit(String productUnit) {
        this.productUnit = productUnit;
    }

    public String getProductPrice() {
        return productPrice;
    }

    public void setProductPrice(String productPrice) {
        this.productPrice = productPrice;
    }

    public String getProductRate() {
        return productRate;
    }

    public void setProductRate(String productRate) {
        this.productRate = productRate;
    }

    public String getProductLowerRate() {
        return productLowerRate;
    }

    public void setProductLowerRate(String productLowerRate) {
        this.productLowerRate = productLowerRate;
    }

    @Override
    public Date getCreateTime() {
        return createTime;
    }

    @Override
    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public List<SettingSupplierInfoVO> getSettingSupplierInfoEntities() {
        return settingSupplierInfoEntities;
    }

    public void setSettingSupplierInfoEntities(List<SettingSupplierInfoVO> settingSupplierInfoEntities) {
        this.settingSupplierInfoEntities = settingSupplierInfoEntities;
    }
}

==> cscec5b-ecxj-impl-3.0.0-20231122.020216-54-sources.jar: com/ejianc/business/ecxj/vo/SettingProductInfoVO.java <==
package com.ejianc.business.ecxj.vo;

import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * 云筑网物资实体
 * 
 * @author generator
 * 
 */
public class SettingProductInfoVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long supplierId; // 招标编号
    private Long tenderProductId; // 云筑物资Id，用于改变云筑网中的状态
    private String tendersNo; // 招标编号
    private String supplierName; // 供应商名称
    private String productName; // 物资名称
    private String productSpec; // 物资类别
    private String productUnit; // 物资计量单位
    private String productPrice; // 云筑物资单价
    private String productRate; // 云筑物资税率

    private BigDecimal fillPrice; // 税前单价/下浮率（填报）
    private String productLowerRate; // 中标供应商联系方式
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date createTime; // 创建时间


    public Long getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(Long supplierId) {
        this.supplierId = supplierId;
    }

    public Long getTenderProductId() {
        return tenderProductId;
    }

    public void setTenderProductId(Long tenderProductId) {
        this.tenderProductId = tenderProductId;
    }

    public String getTendersNo() {
        return tendersNo;
    }

    public void setTendersNo(String tendersNo) {
        this.tendersNo = tendersNo;
    }

    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }
    public String getProductName() {
        return productName;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }

    public String getProductSpec() {
        return productSpec;
    }

    public void setProductSpec(String productSpec) {
        this.productSpec = productSpec;
    }

    public String getProductUnit() {
        return productUnit;
    }

    public void setProductUnit(String productUnit) {
        this.productUnit = productUnit;
    }

    public String getProductPrice() {
        return productPrice;
    }

    public void setProductPrice(String productPrice) {
        this.productPrice = productPrice;
    }

    public String getProductRate() {
        return productRate;
    }

    public void setProductRate(String productRate) {
        this.productRate = productRate;
    }

    public BigDecimal getFillPrice() {
        return fillPrice;
    }

    public void setFillPrice(BigDecimal fillPrice) {
        this.fillPrice = fillPrice;
    }

    public String getProductLowerRate() {
        return productLowerRate;
    }

    public void setProductLowerRate(String productLowerRate) {
        this.productLowerRate = productLowerRate;
    }

    @Override
    public Date getCreateTime() {
        return createTime;
    }

    @Override
    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

}
